@@ -4,8 +4,8 @@ model <- ModelSIRCONN(
     n                   = 10000,
     prevalence          = 0.01,
     contact_rate        = 5,
-    prob_transmission   = 0.4,
-    prob_recovery       = 0.95
+    transmission_rate   = 0.4,
+    recovery_rate       = 0.95
 )
 
 set.seed(1231)
